function opt = fluofitopt(varargin)
%FLUOFITOPT Define fluorescence spectra fitting options.
%   OPT = FLUOFITOPT('OPTION', VALUE, ...) sets fitting option
%   OPTION to VALUE. Multiple options can be given simultaneously.
%   Options that are not given are set to their default values.
%
%   AVAILABLE OPTIONS:
%      global             Fix band shapes across replicates.
%      fixratio           Fix ratio between first and last band.
%      globalratio        Fix ratio across replicates.
%      exfit              Fit excitation spectrum with log-normal.
%      bands              Number of emission bands to fit.
%      iterations         Number of random initializations to try.
%      constraints        {[par band], center, variation, ...}
%                         par is one of {'r','h','n'} for asym, fwhm, pos.
%      defaultconstraints Use some reasonable default constraints.
%      normalize          Normalize spectra before fitting (unimplemented).
%      wavenumber         Fit in the wavenumber domain.
%      redshift           Force second band excitation to be red-shifted.
%
%   EXAMPLE:
%      opt = fluofitopt('bands', 2, 'constraints', {'h1', 3000, 500});
%
%   AUTHOR:
%      Wouter Caarls, MPIbpc <wouter@caarls.org>

  if nargin > 0 && isstruct(varargin{1})
    opt = varargin{1};
    start = 2;
  else
    opt.global = 0;
    opt.fixratio = 1;
    opt.globalratio = 0;
    opt.exfit = 1;
    opt.bands = 3;
    opt.iterations = 10;
    opt.constraints = {};
    opt.defaultconstraints = 1;
    opt.normalize = 1;
    opt.wavenumber = 1;
    opt.redshift = 0;
    start = 1;
  end
  
  for i = start:2:length(varargin)
      if ~isfield(opt, varargin{i})
          error(['Unknown option ''' varargin{i} '''']);
      end
      
      opt = setfield(opt, varargin{i}, varargin{i+1});
  end
  
  